@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use parent qw/autobox/;
 
-our $VERSION = "1.007";
+our $VERSION = "1.008";
 
 =head1 NAME
 
@@ -124,6 +124,14 @@ $array->group_by()
 
 =item
 
+$array->group_by_count()
+
+=item
+
+$array->group_by_array()
+
+=item
+
 $array->flat()
 
 =back
@@ -350,7 +358,8 @@ sub grep_by {
 
 Call the $accessor on each object in the list, or get the hash key
 value on each hashref in the list. Return list of items wich have a
-unique set of return values.
+unique set of return values. The order is preserved. On duplicates,
+keep the first occurrence.
 
 Examples:
 
@@ -540,17 +549,18 @@ sub group_by_array {
 
 =head2 @array->flat() : @array | @$array
 
-Return a flattened array, assuming the array items themselves are
-array refs. I.e.
+Return a (one level) flattened array, assuming the array items
+themselves are array refs. I.e.
 
     [
         [ 1, 2, 3 ],
         [ "a", "b" ],
+        [ [ 1, 2 ], { 3 => 4 } ]
     ]->flat
 
 returns
 
-    [ 1, 2, 3, "a", "b "]
+    [ 1, 2, 3, "a", "b ", [ 1, 2 ], { 3 => 4 } ]
 
 This is useful if e.g. a map_by("some_method") returns arrayrefs of
 objects which you want to do further method calls on. Example:
